"""LaminDB: Manage data & analyses.

Import the package::

   import lamindb as ln

Core database API:

.. autosummary::
   :toctree: .

   view
   select
   Ingest
   load
   add
   delete

Schema API:

.. autosummary::
   :toctree: .

   schema

Knowledge API:

.. autosummary::
   :toctree: .

   knowledge

Dev API:

.. autosummary::
   :toctree: .

   session
   settings
   dev
   link

External API:

.. autosummary::
   :toctree: .

   nb
"""

__version__ = "0.11.0"

import warnings

from lndb_setup import settings  # noqa
from lndb_setup._migrate import check_migrate as _check_migrate

from . import _check_versions  # executes checks during import

if settings.instance.storage_root is None:
    raise RuntimeError("Please run `lndb init` to configure an instance.")
_check_migrate(usettings=settings.user, isettings=settings.instance)

from . import dev  # noqa
from . import knowledge  # noqa
from . import schema  # noqa
from ._delete import delete  # noqa
from ._ingest import Ingest  # noqa
from ._link import link  # noqa
from ._load import load  # noqa
from ._nb import nb  # noqa
from ._view import view  # noqa
from .dev.db import session  # noqa
from .dev.db._add import add  # noqa
from .dev.db._select import select  # noqa

settings.__doc__ = """Settings.

This re-exports `lndb_setup.settings <https://lamin.ai/docs/lndb-setup/lndb_setup.settings>`__.
"""
